@@ -2,6 +2,12 @@
 class SlashException(Exception):
     pass
 
+class HookAlreadyExists(SlashException):
+    pass
+
+class NoActiveSession(SlashException):
+    pass
+
 class CannotLoadTests(SlashException):
     pass
 
