@@ -30,8 +30,9 @@ class SessionLogging(object):
             stack.enter_context(self._get_file_log_handler(filename_template))
             stack.enter_context(self.console_handler)
             stack.enter_context(self.warnings_handler)
-            stack.enter_context(self._process_test_record())
             stack.enter_context(self._get_silenced_logs_context())
+            for extra_handler in _extra_handlers:
+                stack.enter_context(extra_handler)
             yield
 
     def _get_silenced_logs_context(self):
@@ -57,15 +58,20 @@ class SessionLogging(object):
         if fmt is not None:
             handler.format_string = fmt
 
-    def _add_current_test(self, record):
-        record.extra['source'] = context.test_id or context.session.id
-
-    def _process_test_record(self):
-        return logbook.Processor(self._add_current_test)
-
 class SilencedLoggersHandler(logbook.Handler):
     def __init__(self, silence_logger_names):
         super(SilencedLoggersHandler, self).__init__(bubble=False)
         self._silenced_names = set(silence_logger_names)
     def should_handle(self, record):
         return record.channel in self._silenced_names
+
+def add_log_handler(handler):
+    """
+    Adds a log handler to be entered for sessions and for tests
+    """
+    _extra_handlers.append(handler)
+
+def remove_all_extra_handlers():
+    del _extra_handlers[:]
+
+_extra_handlers = []
