@@ -6,12 +6,25 @@ import requests
 class Plugin(PluginInterface):
     def get_name(self):
         return "notifications"
+
+    def activate(self):
+        config.extend({
+            "plugins": {
+                "notifications" : {
+                    "prowl_api_key" : None,
+                    "nma_api_key" : None,
+            }}})
+
+    def deactivate(self):
+        config["plugins"].pop("notifications")
+
     def session_end(self):
         self._notify("Session Ended", "Session {0} ended".format(session.id))
+
     def _notify(self, title, message):
         for url, api_key in [
-                ("https://prowl.weks.net/publicapi/add", config.root.notifications.prowl_api_key),
-                ("https://www.notifymyandroid.com/publicapi/notify", config.root.notifications.nma_api_key),
+                ("https://prowl.weks.net/publicapi/add", config.root.plugins.notifications.prowl_api_key),
+                ("https://www.notifymyandroid.com/publicapi/notify", config.root.plugins.notifications.nma_api_key),
                 ]:
             if api_key is None:
                 continue
